#ifndef DISPLAY_H
#define DISPLAY_H

// **************************************
// Header Files
// **************************************

#include "optionlist.h"
#include "stringarray.h"

// **************************
// Class Definition
// **************************

class Display
{
public:
  /// Constructor.
  Display(void);

  /// Copy Constructor.
  Display(const Display &dis);

  /// Destructor.
  ~Display(void);

  /// Assignment operator.
  Display& operator=(const Display &dis);

  /// Set display depth and optional comment.
  void SetDepth(const MyString& dd, const MyString& com=MyString());

  /// Set display view port and optional comment.
  void SetViewPort(const MyString& vw, const MyString& com=MyString());

  /// Set display virtual size and optional comment.
  void SetVirtual(const MyString& vi, const MyString& com=MyString());

  /// Get display depth.
  const MyString& GetDepth(void) const;

  /// Get display view port.
  const MyString& GetViewPort(void) const;

  /// Get display virtual size.
  const MyString& GetVirtual(void) const;

  /// Get display depth comment.
  const MyString& GetDepthComment(void) const;

  /// Get display view port comment.
  const MyString& GetViewPortComment(void) const;

  /// Get display virtual size comment.
  const MyString& GetVirtualComment(void) const;

  /// Get comments.
  const StringArray& Comments(void) const;

  /// Get comments (as reference).
  StringArray& Comments(void);

  /// Get options.
  const OptionList& Options(void) const;

  /// Get options (as reference).
  OptionList& Options(void);

  /// Get modes.
  const OptionList& Modes(void) const;

  /// Get modes (as reference).
  OptionList& Modes(void);

  /// Celar everything.
  void Clear(void);

  /// Check if everything has correct syntax.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool Check(void);

private:
  MyString depth;        // depth
  MyString viewport;     // view port
  MyString virtualE;     // virtual entry

  // Note: Any additional settings will not be recognized like:
  // FbBpp, Weight, Visual, Black, White.

  MyString depthComment;
  MyString viewportComment;
  MyString virtualEComment;

  StringArray comments;
  OptionList modes;       // screen modes
  OptionList options;
};

#endif // DISPLAY_H
