#include "driveroption.h"

// **************************
// Class Declaration
// **************************

DriverOption::DriverOption(void) : Option()
{   // constructor
  strict=false;
  value="string";
  section="General";
}

DriverOption::~DriverOption(void)
{
}

DriverOption::DriverOption(const DriverOption &dev) : Option(dev)
{ // copy constructor

  defArg=dev.GetDefault();
  arguments=dev.GetArguments();
  strict=dev.IsStrict();
  section=dev.GetSection();
  desc=dev.GetDescription();
}

DriverOption& DriverOption::operator=(const DriverOption &dev)
{ // copy constructor

  Option::operator=(dev);

  defArg=dev.GetDefault();
  arguments=dev.GetArguments();
  strict=dev.IsStrict();
  section=dev.GetSection();
  desc=dev.GetDescription();
  return(*this);
}

const StringArray& DriverOption::GetArguments(void) const
{  // return argument list
  return(arguments);
}

const bool DriverOption::IsStrict(void) const
{                // return if strict
  return(strict);
}

const MyString& DriverOption::GetDefault(void) const
{        // return default argument
  return(defArg);
}

const MyString& DriverOption::GetSection(void) const
{        // return section
  return(section);
}

const MyString& DriverOption::GetDescription(void) const
{        // return description
  return(desc);
}

void DriverOption::SetDefault(const MyString& def)
{    // set default argument

  defArg=def;
}

void DriverOption::SetSection(const MyString& sec)
{    // set section

  section=sec;
}

void DriverOption::SetDescription(const MyString& des)
{    // set description

  desc=des;
}

void DriverOption::AddArgument(const MyString& arg)
{  // add argument

  if (!arg.IsEmpty() && arguments.Find(arg)==-1)
  {  // only add if not in list already
    arguments.Append(arg);
  }
}

void DriverOption::SetStrict(const bool str)
{          // set if strict
  strict=str;
}

void DriverOption::Clear(void)
{   // clear all Options and values

  Option::Clear();
  strict=false;
  defArg.Empty();
  desc.Empty();
  value="string";
  section="General";
  arguments.Clear();
}
