#ifndef DRIVEROPTION_H
#define DRIVEROPTION_H

// **************************************
// Header Files
// **************************************

#include "mystring.h"
#include "stringarray.h"
#include "option.h"

// **************************
// Class Definition
// **************************

class DriverOption : public Option
{
public:
  /// Constructor.
  /**
  * The <i>value</i> will now describe the
  * type of option:
  * - boolean (true or false, 1 ot 0, on or off, yes or no)
  * - integer (decimal or hexadecimal)
  * - string
  */
  DriverOption(void);

  /// Copy Constructor.
  DriverOption(const DriverOption &dev);

  /// Destructor.
  ~DriverOption(void);

  /// Assignment operator.
  DriverOption& operator=(const DriverOption &dev);

  /// Set section.
  void SetSection(const MyString& sec);

  /// Set description.
  void SetDescription(const MyString& des);

  /// Set default value.
  void SetDefault(const MyString& def);

  /// Add new argument.
  void AddArgument(const MyString& arg);

  /// Set if option is strict.
  void SetStrict(const bool str);

  /// Get section.
  const MyString& GetSection(void) const;

  /// Get description.
  const MyString& GetDescription(void) const;

  /// Get default value.
  const MyString& GetDefault(void) const;

  /// Get arguments.
  const StringArray& GetArguments(void) const;

  /// Return if option is strict.
  const bool IsStrict(void) const;

  /// Delete all variables.
  void Clear(void);

private:
  MyString defArg;           ///< Default argument.
  MyString section;          ///< Section for separating otions.
  MyString desc;             ///< Description (longer comment).
  bool strict;               ///< Flag if value is strict.
  StringArray arguments;     ///< List of arguments.
};

#endif // DRIVEROPTION_H
