#ifndef FILELIST_H
#define FILELIST_H

// **************************************
// Header Files
// **************************************

#include "optionlist.h"
#include "stringarray.h"

// **************************
// Class Definition
// **************************

class FileList
{
public:
  /// Constructor.
  FileList(void);

  /// Copy Constructor.
  FileList(const FileList &list);

  /// Destructor.
  ~FileList(void);

  /// Assignment operator.
  FileList& operator=(const FileList &list);

  /// Get comments.
  const StringArray& Comments(void) const;

  /// Get comments (as reference).
  StringArray& Comments(void);

  /// Get font paths.
  const OptionList& FontPaths(void) const;

  /// Get font paths (as reference).
  OptionList& FontPaths(void);

  /// Get module paths.
  const OptionList& ModulePaths(void) const;

  /// Get module paths (as reference).
  OptionList& ModulePaths(void);

  /// Get rgb paths.
  const OptionList& RgbPaths(void) const;

  /// Get rgb paths (as reference).
  OptionList& RgbPaths(void);

  /// Clear everything.
  void Clear(void);

  /// Check if everything has correct syntax.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool Check(void);

private:
  StringArray comments;        // comment
  OptionList fontPaths;       // font paths
  OptionList modulePaths;       // module paths
  OptionList rgbPaths;       // rgb paths
};

#endif // FILELIST_H
