#ifndef INPUTDEVICE_H
#define INPUTDEVICE_H

// **************************************
// Header Files
// **************************************

#include "stringarray.h"
#include "optionlist.h"
#include "driveroptionlist.h"

// **************************
// Class Definition
// **************************

class InputDevice
{
public:
  /// Constructor.
  InputDevice(void);

  /// Copy Constructor.
  InputDevice(const InputDevice &dev);

  /// Destructor.
  ~InputDevice(void);

  /// Assignment operator.
  InputDevice& operator=(const InputDevice &dev);

  /// Set device identifier and optional comment.
  void SetId(const MyString& id, const MyString& com=MyString());

  /// Set device driver and optional comment.
  void SetDriver(const MyString& dr, const MyString& com=MyString());

  /// Get device identifier.
  const MyString& GetId(void) const;

  /// Get device driver.
  const MyString& GetDriver(void) const;

  /// Get device identifier comment.
  const MyString& GetIdComment(void) const;

  /// Get device driver comment.
  const MyString& GetDriverComment(void) const;

  /// Get comments.
  const StringArray& Comments(void) const;

  /// Get comments (as reference).
  StringArray& Comments(void);

  /// Get options.
  const OptionList& Options(void) const;

  /// Get options (as reference).
  OptionList& Options(void);

  /// Clear everything.
  void Clear(void);

  /// Check if everything has correct syntax.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool Check(const bool checkServer=false);

  /// Check if options are correct.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool Check(const DriverOptionList& list);

  /// Compare options with list and set correct cases.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool ConvertOptions(const DriverOptionList& list);

private:
  MyString identifier;      // identifier
  MyString driver;          // driver name
  MyString identifierComment;      // identifier comment
  MyString driverComment;          // driver name comment
  StringArray comments;
  OptionList options;       // options

};

#endif // INPUTDEVICE_H
