#ifndef OPTION_H
#define OPTION_H

// **************************************
// Header Files
// **************************************

#include "mystring.h"

// **************************
// Class Definition
// **************************

class Option
{

friend class DriverOption;
friend class Module;

public:
  /// Constructor.
  Option(void);

  /// Constructor.
  Option(const MyString& opt, const MyString& val=MyString(), const MyString& com=MyString(), const bool act=true);

  /// Copy Constructor.
  Option(const Option &opt);

  /// Destructor.
  ~Option(void);

  /// Assignment operator.
  Option& operator=(const Option &opt);

  /// Set everything
  void Set(const MyString& opt, const MyString& val=MyString(), const MyString& com=MyString(), const bool act=true);

  /// Set option name.
  void SetName(const MyString& opt);

  /// Set option value.
  void SetValue(const MyString& val);

  /// Set option comment.
  void SetComment(const MyString&com);

  /// Mark option as active or inactive.
  void SetActive(const bool act);

  /// Toggle active status.
  void ToogleActive(void);

  /// Get option name.
  const MyString& GetName(void) const;

  /// Get option value.
  const MyString& GetValue(void) const;

  /// Get option comment.
  const MyString& GetComment(void) const;

  /// Get option name.
  const bool IsActive(void) const;

  /// Delete all variables.
  void Clear(void);

  /// Create line for output in xorg file.
  void CreateLine(MyString& line, const unsigned int numTabs=1, const bool val=true, const bool quotes=true, const bool com=true, const MyString& altName="Option", const bool act=true);

  /// Check if everything has correct syntax.
  /**
  * Return <b>true</b> if something is wrong else <b>false</b>.
  */
  const bool Check(void) const;

private:
  MyString name;        ///< Option name.
  MyString value;       ///< Option value.
  MyString comment;     ///< Option comment.
  bool active;          ///< Status of option (active / inactive).
};

#endif // OPTION_H
