#ifndef SETTINGS_H
#define SETTINGS_H

// **************************************
// Header Files
// **************************************

#include "mystring.h"

// **************************
// Class Definition
// **************************

class Settings
{

public:
  Settings(void);
  ~Settings(void);
  Settings(const Settings& set);
  Settings& operator=(const Settings& set);

  const MyString& GetProgDir(void) const;
  const MyString& GetOptionDir(void) const;
  const MyString& GetCurrentDir(void) const;
  const MyString& GetCurrentFilename(void) const;
  const MyString GetCurrentFile(void) const;
  const MyString& GetFilename(void) const;

  const bool GetLoadLastFile(void) const;
  const bool GetSaveSettings(void) const;
  const bool GetShowSplash(void) const;
  const bool GetShowBlank(void) const;
  const bool GetRememberTest(void) const;

  const int GetLanguage(void) const;

  void SetProgDir(const MyString& value);
  void SetOptionDir(const MyString& value);
  void SetCurrentDir(const MyString& value);
  void SetCurrentFilename(const MyString& value);
  void SetFilename(const MyString& value);

  void SetLoadLastFile(const bool value);
  void SetSaveSettings(const bool value);
  void SetShowSplash(const bool value);
  void SetShowBlank(const bool value);
  void SetRememberTest(const bool value);

  void SetLanguage(const int lang);

  /// Load settings in ~/.xorg-edit
  /**
  * Return <b>true</b> if an error occured else <b>false</b>.
  */
  const bool Load(const MyString& filename=MyString());

  /// Save settings in ~/.xorg-edit
  /**
  * Return <b>true</b> if an error occured else <b>false</b>.
  */
  const bool Save(const bool start=false, const MyString& filename=MyString());

private:
  MyString setFile;   // filename for saving and loading settings
  MyString progDir;   // directory where xorg-edit is executed
  MyString optionDir; // directory where options are stored
  MyString curFile;   // current file that is open
  MyString curDir;    // current directory that is open
  bool loadLastFile;  // flag if last opened file should be loaded or /etc/X11/xorg.conf
  bool saveSettings;  // flag if settings should be saved at closing frame
  bool showSplash;    // show splash screen at start
  bool showBlank;     // show message that screen will go blank during test
  bool remTest;       // remeber for test before saving
  int language;        // language

  unsigned int lineNr;         ///< Line counter for reading file.

};

#endif // SETTINGS_H

